summaryrefslogtreecommitdiffstats
path: root/src/usr
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr')
-rw-r--r--src/usr/devtree/bld_devtree.C7
-rw-r--r--src/usr/errl/errlentry.C1
2 files changed, 6 insertions, 2 deletions
diff --git a/src/usr/errl/errlentry.C b/src/usr/errl/errlentry.C
index ed6b11aab..5469a2268 100644
--- a/src/usr/errl/errlentry.C
+++ b/src/usr/errl/errlentry.C
@@ -96,6 +96,7 @@ struct epubTargetTypeToSub_t
// Target type to subsystem table.
static const epubTargetTypeToSub_t TARGET_TO_SUBSYS_TABLE[] =
{
+ { TARGETING::TYPE_NODE , EPUB_CEC_HDW_SUBSYS },
{ TARGETING::TYPE_DIMM , EPUB_MEMORY_DIMM },
{ TARGETING::TYPE_MEMBUF , EPUB_MEMORY_SUBSYS },
{ TARGETING::TYPE_PROC , EPUB_PROCESSOR_SUBSYS },
OpenPOWER on IntegriCloud
diff --git a/src/usr/devtree/bld_devtree.C b/src/usr/devtree/bld_devtree.C
index 622178ae1..a73c81274 100644
--- a/src/usr/devtree/bld_devtree.C
+++ b/src/usr/devtree/bld_devtree.C
@@ -1197,10 +1197,13 @@ errlHndl_t bld_fdt_system(devTree * i_dt, bool i_smallTree)
}
}
}
// just commit any errors we get, this isn't critical
if( errhdl )
{
- errlCommit(errhdl, DEVTREE_COMP_ID);
+ // since there are old parts out in the wild without
+ // this data, we can't log an error
+ delete errhdl;
+ errhdl = NULL;
}
if( !foundvpd ) //serial number not found, default to unavailable
@@ -1197,10 +1197,13 @@ errlHndl_t bld_fdt_system(devTree * i_dt, bool i_smallTree)
}
}
- // just commit any errors we get, this isn't critical
+ // just delete any errors we get, this isn't critical
if( errhdl )
{